@@ -10,7 +10,7 @@ DISPLAY_HEIGHT = 1080
 DISPLAY_WIDTH = 1920
 
 class RadiometricCalibDisplaySession(CalibrationSession, ABC):
-    def __init__(self, camera, radio_calib, path='CalibrationImages/DisplayRadiometric', exposure=13000, numPhaseShift = 4):
+    def __init__(self, camera, radio_calib, path='CalibrationImages/DisplayRadiometric', exposure=60000, numPhaseShift = 4):
         # Set camera, destination path
         self.camera = camera
         self.path = path
@@ -194,6 +194,35 @@ class RadiometricCalibDisplaySession(CalibrationSession, ABC):
         cv2.destroyAllWindows()
         cv2.waitKey(1)
         cv2.waitKey(1)
+        
+    def captureTest(self):
+        cv2.destroyAllWindows()
+        cv2.waitKey(1)
+        cv2.waitKey(1)
+        
+        window_name = 'projector'
+        cv2.namedWindow(window_name)
+        cv2.moveWindow(window_name, self.displayWidth, 0)  #self.displayWidth
+            
+        
+        if not os.path.exists('CalibrationNumpyData/'):
+            os.mkdir('CalibrationNumpyData/')
+        if not os.path.exists('CalibrationNumpyData/DisplayRadiometric/'):
+            os.mkdir('CalibrationNumpyData/DisplayRadiometric/')
+       
+        pattern = np.ones((DISPLAY_HEIGHT,DISPLAY_WIDTH))
+        for i in range(DISPLAY_WIDTH):
+            pattern[:,i] = i / DISPLAY_WIDTH * 255
+        
+        cv2.imshow(window_name, pattern.astype(np.uint8))
+        cv2.waitKey(40)
+        self.camera.getImage(name = 'DisplayRadiometric/'+ 'testImage', calibration=True)
+        
+        print('Capture Complete! Test image viewable at CalibrationImages/DisplayRadiometric/')
+        cv2.waitKey(1000)
+        cv2.destroyAllWindows()
+        cv2.waitKey(1)
+        cv2.waitKey(1)
 
     def avgImagePixel(self):
         pixelValues = []
