@@ -1,6 +1,6 @@
 from abc import ABC
 #from Reconstructions import Mesh
-from GhostScan.Reconstructions import ImageProcessing
+from GhostScan.ImageProcessing import ImageProcessing
 #import wavepy
 import matplotlib.pyplot as plt
 import numpy as np
